View source: R/bso-phenology.R
| bso_translate_phenology | R Documentation |
A BSO generated phenology cannot be analysed in the same way as other phenology objects.
To be able to use the functions that are available for phenology objects
returned by phenology(), the BSO generated phenology should be translated.
bso_translate_phenology(pheno, threshold = 0.1, .quiet = FALSE)
pheno |
A BSO phenology (see |
threshold |
Share of individuals that must have reached a specific development in the BSO phenology to account for them in the corresponding standard phenology. |
.quiet |
If |
Returns a standard phenology as a list. Look here to find out how a phenology can be analysed. It is not recommended to access the list elements directly.
# This may take a few minutes...
# calculate and translate BSO phenology
p <- bso_phenology('bso', barrks_data('stations'), .quiet = TRUE)
pt <- bso_translate_phenology(p, .quiet = TRUE)
# print the generations data frame of station 'Freiburg'
df <- get_generations_df(pt, 'Freiburg')
df
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.