| model.chapy.apply | R Documentation |
This page describes the usage of CHAPY with phenology().
The model specific inputs are listed and its basic functionality is explained.
CHAPY was published by \insertCiteOgris2020;textualbarrks and
parametrized for Pityogenes chalcographus in Slovenia.
tmin, tmean, tmax |
Daily minimum/mean/maximum air temperatures in °C.
For the |
daylength |
Length of the day in hours. Can be created with
|
mode |
Specifies which temperature should be used to calculate the
development. Can be |
.submodels, .onset, .diapause, .mortality, ... |
See |
In barrks, phenology() is used to apply a model. The following code
illustrates which inputs are required to apply CHAPY and which additional
parameters are available.
phenology("chapy", ..., tmin = NULL, tmean = NULL, tmax, daylength, mode = 'max')
# calculate submodels separately
phenology("chapy", ..., .submodels = 'onset', tmax)
phenology("chapy", ..., .submodels = 'diapause', daylength)
phenology("chapy", ..., .submodels = 'mortality', tmax)
phenology("chapy", ..., .submodels = 'development',
.onset, .diapause = NULL, .mortality = NULL,
tmin = NULL, tmean = NULL, tmax = NULL, mode = 'max')
The functioning of CHAPY is identical to RITY but it is has a different parametrization.
model(), phenology(), model.chapy.customize
Other phenology applications:
model.bso.apply,
model.joensson.apply,
model.lange.apply,
model.phenips.apply,
model.phenips_clim.apply,
model.rity.apply
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.