| model.chapy.customize | R Documentation |
This page describes the parameters that can be used to customize CHAPY. The model was developed by \insertCiteOgris2020;textualbarrks. Look here to find out how to apply the model.
dd_onset_start_date |
The date, when the degree days start to sum up ('MM-DD'). |
dd_onset_base |
Base temperature to calculate degree days to trigger the onset. |
dd_onset_threshold |
Degree days that are required to trigger the onset of
infestation. Additionally, the maximum temperature must exceed |
tfly |
Minimum temperature that beetles need to fly. |
dd_development_base |
Base temperature to calculate degree days for development. |
dd_total_dev |
Degree days that are required for a generation to fully develop |
dev_start, dev_end |
Share in total development when the egg development starts and the juvenile beetle's development ends respectively. Usable if the development below/above these thresholds should account for mating, oviposition etc. |
dev_sister_brood |
Share in the total development, when a sister brood will be established. |
dev_mortal_min, dev_mortal_max |
The beetles are considered to be in
white stages (egg, larva, pupa) if their development exceeds |
func_ftmin, func_ftmean, func_ftmax |
Functions to caclulate the air temperature in forest stands (see \insertCiteOgris2019;nobracketsbarrks, equations 1 - 3). Each parameter will be passed as SpatRaster:
|
func_btmin, func_btmean, func_btmax |
Functions to caclulate the bark temperature (see \insertCiteOgris2019;nobracketsbarrks, equations 4 - 6). Each parameter will be passed as SpatRaster:
|
dt_low, dt_up, topt, tmax, alpha, beta, gamma |
Parameters to calculate the effective bark temperature (see \insertCiteOgris2020;nobracketsbarrks, equations A.7 - A.9). |
model_end_date |
Date when the model ends (no further development will be modeled). |
daylength_dia |
When the daylength falls below this threshold, diapause will be initiated. |
mortality_date |
Date when all white stages (egg, larva, pupa) die. |
In barrks, model() is used to customize a model. The following code
illustrates which parameters are available for CHAPY and specifies their
default values.
model("chapy",
# ==== onset ====
dd_onset_start_date = '03-09',
dd_onset_base = 7.4,
dd_onset_threshold = 216.5,
# ==== onset + development ====
tfly = 15.6,
# ==== development ====
dd_development_base = 7.4,
dd_total_dev = 635.4,
dev_start = 0,
dev_end = 1,
dev_sister_brood = 0.5,
dev_mortal_min = NULL,
dev_mortal_max = 0.8,
func_ftmin = function(tmin) { 1.44 + 0.82 * tmin },
func_ftmean = function(tmean) { 0.50 + 0.81 * tmean },
func_ftmax = function(tmax) { 1.03 + 0.86 * tmax },
func_btmin = function(atmin) { 0.56 + 0.99 * atmin },
func_btmean = function(atmean) { -0.48 + 1.03 * atmean },
func_btmax = function(atmax) { 0.03 + 0.99 * atmax },
dt_low = 7.4,
dt_up = 39.4,
topt = 30,
tmax = 41.97,
alpha = 0.031,
beta = 5.3,
gamma = 1.25,
model_end_date = '12-31',
# ==== diapause ====
daylength_dia = 13.6,
# ==== mortality ====
mortality_date = '12-31'
)
model(), phenology(), model.chapy.apply
Other model customizations:
model.bso.customize,
model.joensson.customize,
model.lange.customize,
model.phenips.customize,
model.phenips_clim.customize,
model.rity.customize
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.