| model.joensson.customize | R Documentation |
This page describes the parameters that can be used to customize the Jönsson model. The model was developed by \insertCiteJonsson2011;textualbarrks. Look here to find out how to apply the model.
dd_onset_start_date |
The date, when the degree days start to sum up ('MM-DD'). |
dd_onset_base |
Base temperature to calculate degree days to trigger the onset. |
dd_onset_threshold |
Degree days that are required to trigger the onset of
infestation. Additionally, the maximum temperature must exceed |
tfly |
Minimum temperature that beetles need to fly. |
dd_development_base |
Base temperature to calculate degree days for development. |
dd_total_dev_lower, dd_total_dev_upper |
Lower/upper limit of degree days that are required for a generation to fully develop |
dev_start, dev_end |
Share in total development when the egg development starts and the juvenile beetle's development ends respectively. Usable if the development below/above these thresholds should account for mating, oviposition etc. |
dev_mortal_min, dev_mortal_max |
The beetles are considered to be in
white stages (egg, larva, pupa) if their development exceeds |
model_end_date |
Date when the model ends (no further development will be modeled). |
daylength_dia, tdia_min |
When the daylength falls below |
In barrks, model() is used to customize a model. The following code
illustrates which parameters are available for the Jönsson model and specifies their
default values.
model("joensson",
# ==== onset ====
dd_onset_start_date = '01-01',
dd_onset_base = 5,
dd_onset_threshold = 120,
# ==== onset + development ====
tfly = 20,
# ==== development ====
dd_development_base = 5,
dd_total_dev_lower = 625,
dd_total_dev_upper = 750,
dev_start = 0,
dev_end = 1,
dev_mortal_min = 0,
dev_mortal_max = 1,
model_end_date = '12-31',
# ==== diapause ====
daylength_dia = 19.3,
tdia_min = 15
)
model(), phenology(), model.joensson.apply
Other model customizations:
model.bso.customize,
model.chapy.customize,
model.lange.customize,
model.phenips.customize,
model.phenips_clim.customize,
model.rity.customize
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.