| model.lange.apply | R Documentation |
This page describes the usage of the the Lange model with phenology().
The model specific inputs are listed and its basic functionality is explained.
The model was published by \insertCiteLange2008;textualbarrks for
Ips typographus.
tmin, tmean, tmax |
Daily minimum/mean/maximum temperatures in °C. |
.submodels, .onset, .diapause, .mortality, ... |
See |
In barrks, phenology() is used to apply a model. The following code
illustrates which inputs are required to apply the Lange model and which additional
parameters are available.
phenology("lange", ..., tmin, tmean, tmax)
# calculate submodels separately
phenology("lange", ..., .submodels = 'onset', tmean, tmax)
phenology("lange", ..., .submodels = 'mortality', tmin)
phenology("lange", ..., .submodels = 'development',
.onset, .diapause = NULL, .mortality = NULL,
tmean, tmax)
The function returns a phenology. Look here to find out how it can be analysed.
In the following, the basic functioning of the Lange model is explained.
Onset: The onset of swarming is triggerd when the degree days of the maximum temperature reach a specific threshold and the maximum temperature exceeds the minimum flight temperature according to \insertCiteAnnila1969;textualbarrks.
Development: The development is calculated using stage-specific temperature sums and thresholds \insertCiteWermelinger1998barrks. A new generation starts its development when the last generation finished its development and the maximum temperature exceeds the minimum flight temperature.
Diapause: The Lange model does not have a diapause submodel implemented.
Mortality: White stages (egg to pupa) die when the minimum temperature falls below a specific threshold.
Look here to find out how the model parameters affect the actual calculations and which values are used by default.
model(), phenology(), model.lange.customize
Other phenology applications:
model.bso.apply,
model.chapy.apply,
model.joensson.apply,
model.phenips.apply,
model.phenips_clim.apply,
model.rity.apply
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.