| model.rity.apply | R Documentation |
This page describes the usage of RITY with phenology().
The model specific inputs are listed and its basic functionality is explained.
RITY (also called RITY-2) was published by \insertCiteOgris2019;textualbarrks and
parametrized for Ips typographus in Slovenia.
tmin, tmean, tmax |
Daily minimum/mean/maximum temperatures in °C.
For the |
daylength |
Length of the day in hours. Can be created with
|
mode |
Specifies which temperature should be used to calculate the
development. Can be |
.submodels, .onset, .diapause, .mortality, ... |
See |
In barrks, phenology() is used to apply a model. The following code
illustrates which inputs are required to apply RITY and which additional
parameters are available.
phenology("rity", ..., tmin = NULL, tmean = NULL, tmax, daylength, mode = 'max')
# calculate submodels separately
phenology("rity", ..., .submodels = 'onset', tmax)
phenology("rity", ..., .submodels = 'diapause', daylength)
phenology("rity", ..., .submodels = 'mortality', tmax)
phenology("rity", ..., .submodels = 'development',
.onset, .diapause = NULL, .mortality = NULL,
tmin = NULL, tmean = NULL, tmax = NULL, mode = 'max')
The function returns a phenology. Look here to find out how it can be analysed.
In the following, the basic functioning of RITY is explained.
Onset: See PHENIPS.
Development: Based on PHENIPS with a few modifications:
The optimum curve is calculated according to \insertCiteWermelinger1998;textualbarrks without simplification.
The minimum, mean or maximum bark temperature can be used to calculate the development. These temperatures depend only on the respective air temperatures.
Diapause: See PHENIPS.
Mortality: See PHENIPS.
Look here to find out how the model parameters affect the actual calculations and which values are used by default.
model(), phenology(), model.rity.customize
Other phenology applications:
model.bso.apply,
model.chapy.apply,
model.joensson.apply,
model.lange.apply,
model.phenips.apply,
model.phenips_clim.apply
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.